
==========
javasphinx
==========

javasphinx is an extension to the Sphinx documentation system which adds support
for documenting Java projects. It includes a Java domain for writing
documentation manually and a javasphinx-apidoc utility which will automatically
generate API documentation from existing Javadoc markup.
